# NetworkDetailedStats

Detailed network statistics 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**connections_current** | **int** | The total number of connections currently established or establishing. This value is a guage, meaning it is not monotonic.  | 
**connections_timedout** | **int** | The number of times a connection attempt failed because it took too long to establish | 
**connections_host_not_found** | **int** | The number of times a connection attempt failed because a host lookup failed | 
**connections_reset** | **int** | The number of times a connection attempt failed because the target host reset the connection  | 
**connections_tls_validation_failed** | **int** | The number of times a connection attempt failed because TLS validation did not succeed  | 
**connections_other_failure** | **int** | The number of times a connection attempt failed for reasons other than the explicitly enumerated ones.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


